@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::GENEHACK;
 our $AUTHORITY = 'cpan:GENEHACK';
-$Dist::Zilla::PluginBundle::GENEHACK::VERSION = '0.700';
+$Dist::Zilla::PluginBundle::GENEHACK::VERSION = '0.8';
 # ABSTRACT: BeLike::GENEHACK when you zilla your dist
 
 
@@ -24,7 +24,6 @@ use Dist::Zilla::Plugin::TaskWeaver;
 use Dist::Zilla::Plugin::PodWeaver;
 use Dist::Zilla::Plugin::MetaConfig;
 use Dist::Zilla::Plugin::MetaJSON;
-use Dist::Zilla::Plugin::GithubMeta;
 use Dist::Zilla::Plugin::InstallGuide;
 use Dist::Zilla::Plugin::CopyFilesFromBuild;
 use Dist::Zilla::Plugin::NextRelease;
@@ -100,13 +99,7 @@ sub configure {
     'MetaJSON' ,
   );
 
-  my $github_meta_config = { issues => 1 };
-  $github_meta_config->{homepage} = $self->homepage
-    if $self->homepage;
-
   $self->add_plugins(
-    [ 'GithubMeta' => $github_meta_config ] ,
-
     # auto-make INSTALL
     'InstallGuide' ,
 
@@ -125,7 +118,7 @@ sub configure {
 
     # oh, so very good
     'Test::EOL' ,
-    'Test::Compile' ,
+    ['Test::Compile' => { bail_out_on_fail => 1 } ],
 
     # git magic
     ['Git::Commit' => { add_files_in => 'releases/' } ],
@@ -171,7 +164,7 @@ Dist::Zilla::PluginBundle::GENEHACK - BeLike::GENEHACK when you zilla your dist
 
 =head1 VERSION
 
-version 0.700
+version 0.8
 
 =head1 SYNOPSIS
 
@@ -191,40 +184,57 @@ this:
     [Git::NextVersion]
 
     [AutoPrereqs]
+
     [CheckChangesHasContent]
+
+    [PkgVersion]
+
     [Authority]
     authority='cpan:GENEHACK'
     do_metadata=1
+
     [MinimumPerl]
-    [PkgVersion]
+
     [Taskweaver]   ; if is_task is set
     [PodWeaver]    ; if is_task is NOT set
+
     [MetaConfig]
+
     [MetaJSON]
-    [GithubMeta]
-    ; if needed, override homepage with 'homepage' param to @GENEHACK
-    issues = 1
+
     [InstallGuide]
+
     [CopyFilesFromBuild]
     copy=INSTALL
+
     [NextRelease]
+
     [ExtraTests]
+
     [PodCoverageTests]
     [PodSyntaxTests]
-    [EOLTests]
+
+    [Test::EOL]
     [Test::Compile]
-    [Git::Tag]
+
     [Git::Commit]
     add_files_in = releases/
+    [Git::Tag]
+
     [InstallRelease]
     install_command='cpanm .'
+
     [Git::Push]
+
     [Twitter]
+
     [Run::BeforeBuild]
     run = rm -f Makefile.PL
+
     [Run::AfterBuild]
     run = cp %d/Makefile.PL ./
     run = git status --porcelain | grep 'M Makefile.PL' && git commit -m 'auto-committed by dist.ini' Makefile.PL || echo Makefile.PL up to date
+
     [Run::Release]
     run = mv %a ./releases/
     add_files_in = releases/
@@ -233,11 +243,11 @@ this:
 
 =head1 AUTHOR
 
-John SJ Anderson <genehack@genehack.org>
+John SJ Anderson <john@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2020 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
